from django.conf.urls import url
from .views import *


urlpatterns = [
    url(r'^request_code/$', request_code, name="request_code"),
    url(r'^submit/$', submit, name="submit"),
    url(r'^logout/$', logout, name="logout")
]


from django.apps import AppConfig
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


class TelegramAuthConfig(AppConfig):
    name = 'django_telethon_authorization'

    def ready(self):
        if not (
            settings.TG_API_ID and
            settings.TG_API_HASH
        ):
            raise ImproperlyConfigured(
                "\nIn order to use django-telethon-authorization you must set environment variables:\n"
                "TG_API_ID\n"
                "TG_API_HASH"
            )



from django.http import JsonResponse


class DTAException(Exception):
    """ Base exception which could represent itself as a JSON response"""
    def __init__(self, message):
        self.message = message

    def to_response(self):
        return JsonResponse({"success": False, "message": self.message})


class PayloadException(DTAException):
    pass


class TelegramAuthorizationException(DTAException):
    pass
